@@ -109,6 +109,30 @@ int setup_module_auto_defines(PyObject * module)
 	result += PyModule_AddIntMacro(module, NETID_ISM_LOGGER);
 	result += PyModule_AddIntMacro(module, NETID_CAN_SWITCH);
 	result += PyModule_AddIntMacro(module, NETID_WBMS);
+	result += PyModule_AddIntMacro(module, NETID_WBMS2);
+	result += PyModule_AddIntMacro(module, NETID_DWCAN_09);
+	result += PyModule_AddIntMacro(module, NETID_DWCAN_10);
+	result += PyModule_AddIntMacro(module, NETID_DWCAN_11);
+	result += PyModule_AddIntMacro(module, NETID_DWCAN_12);
+	result += PyModule_AddIntMacro(module, NETID_DWCAN_13);
+	result += PyModule_AddIntMacro(module, NETID_DWCAN_14);
+	result += PyModule_AddIntMacro(module, NETID_DWCAN_15);
+	result += PyModule_AddIntMacro(module, NETID_DWCAN_16);
+	result += PyModule_AddIntMacro(module, NETID_LIN_07);
+	result += PyModule_AddIntMacro(module, NETID_LIN_08);
+	result += PyModule_AddIntMacro(module, NETID_SPI2);
+	result += PyModule_AddIntMacro(module, NETID_MDIO_01);
+	result += PyModule_AddIntMacro(module, NETID_MDIO_02);
+	result += PyModule_AddIntMacro(module, NETID_MDIO_03);
+	result += PyModule_AddIntMacro(module, NETID_MDIO_04);
+	result += PyModule_AddIntMacro(module, NETID_MDIO_05);
+	result += PyModule_AddIntMacro(module, NETID_MDIO_06);
+	result += PyModule_AddIntMacro(module, NETID_MDIO_07);
+	result += PyModule_AddIntMacro(module, NETID_MDIO_08);
+	result += PyModule_AddIntMacro(module, NETID_OP_ETHERNET13);
+	result += PyModule_AddIntMacro(module, NETID_OP_ETHERNET14);
+	result += PyModule_AddIntMacro(module, NETID_OP_ETHERNET15);
+	result += PyModule_AddIntMacro(module, NETID_OP_ETHERNET16);
 	result += PyModule_AddIntMacro(module, NETID_MAX);
 	result += PyModule_AddIntMacro(module, NETID_INVALID);
 	result += PyModule_AddIntMacro(module, NEODEVICE_UNKNOWN);
@@ -146,6 +170,10 @@ int setup_module_auto_defines(PyObject * module)
 	result += PyModule_AddIntMacro(module, NEODEVICE_NEW_DEVICE_59);
 	result += PyModule_AddIntMacro(module, NEODEVICE_RAD_BMS);
 	result += PyModule_AddIntMacro(module, NEODEVICE_RADMOON3);
+	result += PyModule_AddIntMacro(module, NEODEVICE_RADCOMET);
+	result += PyModule_AddIntMacro(module, NEODEVICE_FIRE3_FLEXRAY);
+	result += PyModule_AddIntMacro(module, NEODEVICE_RED2_OEM);
+	result += PyModule_AddIntMacro(module, NEODEVICE_NEW_DEVICE_27);
 	result += PyModule_AddIntMacro(module, NEODEVICE_RED);
 	result += PyModule_AddIntMacro(module, NEODEVICE_ECU);
 	result += PyModule_AddIntMacro(module, NEODEVICE_IEVB);
@@ -236,6 +264,7 @@ int setup_module_auto_defines(PyObject * module)
 	result += PyModule_AddIntMacro(module, SPY_PROTOCOL_AUTOSAR);
 	result += PyModule_AddIntMacro(module, SPY_PROTOCOL_A2B);
 	result += PyModule_AddIntMacro(module, SPY_PROTOCOL_WBMS);
+	result += PyModule_AddIntMacro(module, SPY_PROTOCOL_MDIO);
 	result += PyModule_AddIntMacro(module, SPY_STATUS_GLOBAL_ERR);
 	result += PyModule_AddIntMacro(module, SPY_STATUS_TX_MSG);
 	result += PyModule_AddIntMacro(module, SPY_STATUS_XTD_FRAME);
@@ -289,6 +318,16 @@ int setup_module_auto_defines(PyObject * module)
 	result += PyModule_AddIntMacro(module, SPY_STATUS2_I2C_ERR_TIMEOUT);
 	result += PyModule_AddIntMacro(module, SPY_STATUS2_I2C_ERR_NACK);
 	result += PyModule_AddIntMacro(module, SPY_STATUS2_I2C_DIR_READ);
+	result += PyModule_AddIntMacro(module, SPY_STATUS2_MDIO_ERR_TIMEOUT);
+	result += PyModule_AddIntMacro(module, SPY_STATUS2_MDIO_JOB_CANCELLED);
+	result += PyModule_AddIntMacro(module, SPY_STATUS2_MDIO_INVALID_BUS);
+	result += PyModule_AddIntMacro(module, SPY_STATUS2_MDIO_INVALID_PHYADDR);
+	result += PyModule_AddIntMacro(module, SPY_STATUS2_MDIO_INVALID_REGADDR);
+	result += PyModule_AddIntMacro(module, SPY_STATUS2_MDIO_UNSUPPORTED_CLAUSE);
+	result += PyModule_AddIntMacro(module, SPY_STATUS2_MDIO_UNSUPPORTED_OPCODE);
+	result += PyModule_AddIntMacro(module, SPY_STATUS2_MDIO_OVERFLOW);
+	result += PyModule_AddIntMacro(module, SPY_STATUS2_MDIO_CLAUSE45);
+	result += PyModule_AddIntMacro(module, SPY_STATUS2_MDIO_READ);
 	result += PyModule_AddIntMacro(module, SPY_STATUS2_LIN_ERR_RX_BREAK_NOT_0);
 	result += PyModule_AddIntMacro(module, SPY_STATUS2_LIN_ERR_RX_BREAK_TOO_SHORT);
 	result += PyModule_AddIntMacro(module, SPY_STATUS2_LIN_ERR_RX_SYNC_NOT_55);
@@ -307,7 +346,6 @@ int setup_module_auto_defines(PyObject * module)
 	result += PyModule_AddIntMacro(module, SPY_STATUS3_LIN_SLAVE_DATA_TOO_SHORT);
 	result += PyModule_AddIntMacro(module, SPY_STATUS3_LIN_ONLY_UPDATE_SLAVE_TABLE_ONCE);
 	result += PyModule_AddIntMacro(module, SPY_STATUS2_MOST_PACKET_DATA);
-	result += PyModule_AddIntMacro(module, SPY_STATUS2_MOST_STATUS);
 	result += PyModule_AddIntMacro(module, SPY_STATUS2_MOST_LOW_LEVEL);
 	result += PyModule_AddIntMacro(module, SPY_STATUS2_MOST_CONTROL_DATA);
 	result += PyModule_AddIntMacro(module, SPY_STATUS2_MOST_MHP_USER_DATA);
@@ -324,6 +362,9 @@ int setup_module_auto_defines(PyObject * module)
 	result += PyModule_AddIntMacro(module, SPY_STATUS2_ETHERNET_UPDATE_CHECKSUMS);
 	result += PyModule_AddIntMacro(module, SPY_STATUS2_ETHERNET_MANUALFCS_ENABLED);
 	result += PyModule_AddIntMacro(module, SPY_STATUS2_ETHERNET_FCS_VERIFIED);
+	result += PyModule_AddIntMacro(module, SPY_STATUS2_ETHERNET_T1S_SYMBOL);
+	result += PyModule_AddIntMacro(module, SPY_STATUS2_ETHERNET_T1S_BURST);
+	result += PyModule_AddIntMacro(module, SPY_STATUS2_ETHERNET_T1S_ETHERNET);
 	result += PyModule_AddIntMacro(module, SPY_STATUS2_FLEXRAY_TX_AB);
 	result += PyModule_AddIntMacro(module, SPY_STATUS2_FLEXRAY_TX_AB_NO_A);
 	result += PyModule_AddIntMacro(module, SPY_STATUS2_FLEXRAY_TX_AB_NO_B);
@@ -332,8 +373,7 @@ int setup_module_auto_defines(PyObject * module)
 	result += PyModule_AddIntMacro(module, SPY_STATUS2_FLEXRAY_NO_HEADERCRC);
 	result += PyModule_AddIntMacro(module, SPY_STATUS2_CAN_ISO15765_LOGICAL_FRAME);
 	result += PyModule_AddIntMacro(module, SPY_STATUS2_CAN_HAVE_LINK_DATA);
-	result += PyModule_AddIntMacro(module, SPY_STATUS2_WBMS_NODE_DISCONNECTED);
-	result += PyModule_AddIntMacro(module, SPY_STATUS2_I2C_NODE_FAULT);
+	result += PyModule_AddIntMacro(module, SPY_STATUS2_WBMS_API_IS_CALLBACK);
 	result += PyModule_AddIntMacro(module, SPY_STATUS3_CANFD_ESI);
 	result += PyModule_AddIntMacro(module, SPY_STATUS3_CANFD_IDE);
 	result += PyModule_AddIntMacro(module, SPY_STATUS3_CANFD_RTR);
@@ -373,6 +413,19 @@ int setup_module_auto_defines(PyObject * module)
 	result += PyModule_AddIntMacro(module, HARDWARE_TIMESTAMP_ID_NEORED_10US);
 	result += PyModule_AddIntMacro(module, HARDWARE_TIMESTAMP_ID_NEORED_25NS);
 	result += PyModule_AddIntMacro(module, HARDWARE_TIMESTAMP_ID_NEORED_10NS);
+	result += PyModule_AddIntMacro(module, HADRWARE_TIMESTAMP_ID_FIXED);
+	result += PyModule_AddIntMacro(module, FIRE2_REPORT_PERIODIC);
+	result += PyModule_AddIntMacro(module, FIRE2_REPORT_EMISC1_DIGITAL);
+	result += PyModule_AddIntMacro(module, FIRE2_REPORT_EMISC2_DIGITAL);
+	result += PyModule_AddIntMacro(module, FIRE2_REPORT_MISC5_DIGITAL);
+	result += PyModule_AddIntMacro(module, FIRE2_REPORT_MISC6_DIGITAL);
+	result += PyModule_AddIntMacro(module, FIRE2_REPORT_EMISC1_ANALOG);
+	result += PyModule_AddIntMacro(module, FIRE2_REPORT_EMISC2_ANALOG);
+	result += PyModule_AddIntMacro(module, FIRE2_REPORT_VBATT_ANALOG);
+	result += PyModule_AddIntMacro(module, FIRE2_REPORT_TEMP_ANALOG);
+	result += PyModule_AddIntMacro(module, FIRE2_REPORT_PWM_IN);
+	result += PyModule_AddIntMacro(module, FIRE2_REPORT_GPS);
+	result += PyModule_AddIntMacro(module, FIRE3_REPORT_ORIENTATION);
 	result += PyModule_AddIntMacro(module, CANNODE_STATUS_COREMINI_IS_RUNNING);
 	result += PyModule_AddIntMacro(module, CANNODE_STATUS_IN_BOOTLOADER);
 	result += PyModule_AddIntMacro(module, MAIN_VNET);
@@ -380,6 +433,11 @@ int setup_module_auto_defines(PyObject * module)
 	result += PyModule_AddIntMacro(module, SLAVE_VNET_B);
 	result += PyModule_AddIntMacro(module, WIFI_CONNECTION);
 	result += PyModule_AddIntMacro(module, REGISTER_BY_SERIAL);
+	result += PyModule_AddIntMacro(module, TCP_SUPPORTED);
+	result += PyModule_AddIntMacro(module, DRIVER_MASK);
+	result += PyModule_AddIntMacro(module, DRIVER_USB1);
+	result += PyModule_AddIntMacro(module, DRIVER_USB2);
+	result += PyModule_AddIntMacro(module, DRIVER_USB3);
 	// enum
 	result += PyModule_AddIntMacro(module, AUTO);
 	result += PyModule_AddIntMacro(module, USE_TQ);
@@ -497,26 +555,85 @@ int setup_module_auto_defines(PyObject * module)
 	result += PyModule_AddIntMacro(module, ETHERNET_SETTINGS2_FLAG_RTSP_ENABLE);
 	result += PyModule_AddIntMacro(module, ETHERNET_SETTINGS2_FLAG_DEVICE_HOSTING_ENABLE);
 	result += PyModule_AddIntMacro(module, ETHERNET_SETTINGS2_FLAG_CONFIG_NOT_ALLOWED);
+	result += PyModule_AddIntMacro(module, ETHERNET_SETTINGS2_FLAG_ICS_SFP);
 	result += PyModule_AddIntMacro(module, ETHERNET_SETTINGS2_FLAG_COMM_IN_USE);
-	result += PyModule_AddIntMacro(module, ETHERNET_SETTINGS2_SIZE);
+	result += PyModule_AddIntMacro(module, ETHERNET_SETTINGS2_FLAG2_LINK_MODE);
+	result += PyModule_AddIntMacro(module, ETHERNET_SETTINGS2_FLAG2_PHY_MODE);
+	result += PyModule_AddIntMacro(module, ETHERNET_SETTINGS2_FLAG2_LINK_MODE_AUTO);
+	result += PyModule_AddIntMacro(module, ETHERNET_SETTINGS2_FLAG2_SFP_ID_SHIFT);
+	result += PyModule_AddIntMacro(module, ETHERNET_SETTINGS2_FLAG2_SFP_ID_MASK);
 	// enum
-	result += PyModule_AddIntMacro(module, LINK_SPEED_AUTO_NEGOTIATION);
-	result += PyModule_AddIntMacro(module, LINK_SPEED_1GBPS_FULL_DUPLEX);
-	result += PyModule_AddIntMacro(module, LINK_SPEED_1GBPS_HALF_DUPLEX);
-	result += PyModule_AddIntMacro(module, LINK_SPEED_100MBPS_FULL_DUPLEX);
-	result += PyModule_AddIntMacro(module, LINK_SPEED_100MBPS_HALF_DUPLEX);
-	result += PyModule_AddIntMacro(module, LINK_SPEED_10MBPS_FULL_DUPLEX);
-	result += PyModule_AddIntMacro(module, LINK_SPEED_10MBPS_HALF_DUPLEX);
-	result += PyModule_AddIntMacro(module, LINK_SPEED_COUNT);
-	// end of enum -  };
+	result += PyModule_AddIntMacro(module, SFP_ID_UNKNOWN);
+	result += PyModule_AddIntMacro(module, SFP_ID_FINISAR_FCLF8522P2BTL);
+	result += PyModule_AddIntMacro(module, SFP_ID_FS_GB_GE_T);
+	result += PyModule_AddIntMacro(module, SFP_ID_ICS_MV2112A2);
+	result += PyModule_AddIntMacro(module, SFP_ID_ICS_MV2221MB1);
+	result += PyModule_AddIntMacro(module, SFP_ID_ICS_MV3244);
+	result += PyModule_AddIntMacro(module, SFP_ID_MAX);
+	// end of enum -  } SfpId;
 
+	result += PyModule_AddIntMacro(module, ETHERNET_SETTINGS2_SIZE);
 	result += PyModule_AddIntMacro(module, ETHERNET_SETTINGS10G_FLAG_FULL_DUPLEX);
 	result += PyModule_AddIntMacro(module, ETHERNET_SETTINGS10G_FLAG_AUTO_NEG);
 	result += PyModule_AddIntMacro(module, ETHERNET_SETTINGS10G_FLAG_TCPIP_ENABLE);
 	result += PyModule_AddIntMacro(module, ETHERNET_SETTINGS10G_FLAG_RTSP_ENABLE);
 	result += PyModule_AddIntMacro(module, ETHERNET_SETTINGS10G_FLAG_DEVICE_HOSTING_ENABLE);
+	result += PyModule_AddIntMacro(module, ETHERNET_SETTINGS10G_FLAG_CONFIG_NOT_ALLOWED);
+	result += PyModule_AddIntMacro(module, ETHERNET_SETTINGS10G_FLAG_ICS_SFP);
+	result += PyModule_AddIntMacro(module, ETHERNET_SETTINGS10G_FLAG_LINK_MODE);
+	result += PyModule_AddIntMacro(module, ETHERNET_SETTINGS10G_FLAG_PHY_MODE);
+	result += PyModule_AddIntMacro(module, ETHERNET_SETTINGS10G_FLAG_LINK_MODE_AUTO);
 	result += PyModule_AddIntMacro(module, ETHERNET_SETTINGS10G_FLAG_COMM_IN_USE);
 	result += PyModule_AddIntMacro(module, ETHERNET10G_SETTINGS_SIZE);
+	result += PyModule_AddIntMacro(module, ETHERNET10T1S_SETTINGS_SIZE);
+	result += PyModule_AddIntMacro(module, ETHERNET10T1S_SETTINGS_FLAG_ENABLE_PLCA);
+	result += PyModule_AddIntMacro(module, ETHERNET10T1S_SETTINGS_FLAG_TERMINATION);
+	result += PyModule_AddIntMacro(module, ETHERNET10T1S_SETTINGS_FLAG_BUS_DECODING_BEACONS);
+	result += PyModule_AddIntMacro(module, ETHERNET10T1S_SETTINGS_FLAG_BUS_DECODING_ALL);
+	// enum
+	result += PyModule_AddIntMacro(module, MACSEC_PACKET_NO_VLAN_OR_MPLS);
+	result += PyModule_AddIntMacro(module, MACSEC_PACKET_SINGLE_VLAN);
+	result += PyModule_AddIntMacro(module, MACSEC_PACKET_DUAL_VLAN);
+	result += PyModule_AddIntMacro(module, MACSEC_PACKET_MPLS);
+	result += PyModule_AddIntMacro(module, MACSEC_PACKET_SINGLE_VLAN_FOLLOW_BY_MPLS);
+	result += PyModule_AddIntMacro(module, MACSEC_PACKET_DUAL_VLAN_FOLLOW_BY_MPLS);
+	result += PyModule_AddIntMacro(module, MACSEC_PACKET_UNSUPPORTED_TYPE);
+	// end of enum -  } MACSEC_PACKET_TYPE;
+
+	result += PyModule_AddIntMacro(module, MACSEC_SETTINGS_RULE_SIZE);
+	result += PyModule_AddIntMacro(module, MACSEC_SETTINGS_MAP_SIZE);
+	// enum
+	result += PyModule_AddIntMacro(module, MACSEC_VF_DISABLED);
+	result += PyModule_AddIntMacro(module, MACSEC_VF_CHECK);
+	result += PyModule_AddIntMacro(module, MACSEC_VF_STRICT);
+	result += PyModule_AddIntMacro(module, MACSEC_VF_NA);
+	// end of enum -  } MACSEC_VALIDATEFRAME;
+
+	// enum
+	result += PyModule_AddIntMacro(module, MACSEC_SECTAG_ICV_BOTH_STRIP);
+	result += PyModule_AddIntMacro(module, MACSEC_SECTAG_ICV_RESERVED);
+	result += PyModule_AddIntMacro(module, MACSEC_SECTAG_ICV_STRIP_ICV_ONLY);
+	result += PyModule_AddIntMacro(module, MACSEC_SECTAG_ICV_NO_STRIP);
+	// end of enum -  } MACSEC_STRIP_SECTAG_ICV;
+
+	// enum
+	result += PyModule_AddIntMacro(module, MACSEC_CIPHER_GCM_AES_128);
+	result += PyModule_AddIntMacro(module, MACSEC_CIPHER_GCM_AES_256);
+	result += PyModule_AddIntMacro(module, MACSEC_CIPHER_GCM_AES_128_XPN);
+	result += PyModule_AddIntMacro(module, MACSEC_CIPHER_GCM_AES_256_XPN);
+	// end of enum -  } MACSEC_CIPHER_SUITE;
+
+	result += PyModule_AddIntMacro(module, MACSEC_SETTINGS_SECY_SIZE);
+	result += PyModule_AddIntMacro(module, MACSEC_SETTINGS_SC_SIZE);
+	result += PyModule_AddIntMacro(module, MACSEC_SETTINGS_SA_SIZE);
+	result += PyModule_AddIntMacro(module, MACSEC_SETTINGS_FLAGS_SIZE);
+	result += PyModule_AddIntMacro(module, MACSEC_NUM_FLAGS_PER_CONFIG);
+	result += PyModule_AddIntMacro(module, MACSEC_NUM_RULES_PER_CONFIG);
+	result += PyModule_AddIntMacro(module, MACSEC_NUM_MAPS_PER_CONFIG);
+	result += PyModule_AddIntMacro(module, MACSEC_NUM_SECY_PER_CONFIG);
+	result += PyModule_AddIntMacro(module, MACSEC_NUM_SC_PER_CONFIG);
+	result += PyModule_AddIntMacro(module, MACSEC_NUM_SA_PER_CONFIG);
+	result += PyModule_AddIntMacro(module, MACSEC_SETTINGS_SIZE);
 	result += PyModule_AddIntMacro(module, LOGGER_SETTINGS_SIZE);
 	result += PyModule_AddIntMacro(module, DISK_SETTINGS_SIZE);
 	result += PyModule_AddIntMacro(module, CANTERM_SETTINGS_SIZE);
@@ -560,11 +677,17 @@ int setup_module_auto_defines(PyObject * module)
 	result += PyModule_AddIntMacro(module, swUpdateGetProgress);
 	result += PyModule_AddIntMacro(module, swUpdateValidateAll);
 	result += PyModule_AddIntMacro(module, swUpdateGetBufferSize);
-	result += PyModule_AddIntMacro(module, swUpdateCheckVersion);
+	result += PyModule_AddIntMacro(module, swUpdateCheckHostVersion);
+	result += PyModule_AddIntMacro(module, swUpdateValidateComponent);
+	result += PyModule_AddIntMacro(module, swUpdateFinalize);
+	result += PyModule_AddIntMacro(module, swUpdateGetCommunicationVersion);
 	// end of enum -  };
 
 	result += PyModule_AddIntMacro(module, SExtSubCmdHdr_SIZE);
-	result += PyModule_AddIntMacro(module, SExtSubCmdComm_SIZE);
+	result += PyModule_AddIntMacro(module, GENERIC_BINARY_STATUS_ERROR_UNKNOWN_BINARY);
+	result += PyModule_AddIntMacro(module, GENERIC_BINARY_STATUS_ERROR_OVERSIZE);
+	result += PyModule_AddIntMacro(module, GENERIC_BINARY_STATUS_ERROR_BINARY_EMPTY);
+	result += PyModule_AddIntMacro(module, GENERIC_BINARY_STATUS_ERROR_ANY_MASK);
 	result += PyModule_AddIntMacro(module, SERDESCAM_SETTINGS_FLAG_ENABLE);
 	result += PyModule_AddIntMacro(module, SERDESCAM_SETTINGS_FLAG_RTSP_ENABLE);
 	result += PyModule_AddIntMacro(module, SERDESCAM_SETTINGS_FLAG_AUTO_DET_RES_ENABLE);
@@ -792,6 +915,7 @@ int setup_module_auto_defines(PyObject * module)
 	result += PyModule_AddIntMacro(module, A2BMonitorSettings_SIZE);
 	result += PyModule_AddIntMacro(module, SRADA2BSettings_SIZE);
 	result += PyModule_AddIntMacro(module, SRADMoon2Settings_SIZE);
+	result += PyModule_AddIntMacro(module, SRADMoon3Settings_SIZE);
 	result += PyModule_AddIntMacro(module, SRADGigalogSettings_SIZE);
 	result += PyModule_AddIntMacro(module, SRADGigastarSettings_SIZE);
 	result += PyModule_AddIntMacro(module, SVividCANSettings_SIZE);
@@ -835,9 +959,6 @@ int setup_module_auto_defines(PyObject * module)
 	result += PyModule_AddIntMacro(module, VCAN4IndSettings_SIZE);
 	result += PyModule_AddIntMacro(module, OBD2LCSettings_SIZE);
 	result += PyModule_AddIntMacro(module, RADJUPITER_NUM_PORTS);
-	result += PyModule_AddIntMacro(module, JUPITER_PTP_ROLE_DISABLED);
-	result += PyModule_AddIntMacro(module, JUPITER_PTP_ROLE_MASTER);
-	result += PyModule_AddIntMacro(module, JUPITER_PTP_ROLE_SLAVE);
 	result += PyModule_AddIntMacro(module, SRADJupiterSettings_SIZE);
 	result += PyModule_AddIntMacro(module, LINUX_BOOT_ALLOWED);
 	result += PyModule_AddIntMacro(module, WIFI_ANTENNA_INTERNAL);
@@ -845,12 +966,52 @@ int setup_module_auto_defines(PyObject * module)
 	result += PyModule_AddIntMacro(module, LINUX_CONFIG_PORT_NONE);
 	result += PyModule_AddIntMacro(module, LINUX_CONFIG_PORT_ETH_01);
 	result += PyModule_AddIntMacro(module, LINUX_CONFIG_PORT_ETH_02);
+	result += PyModule_AddIntMacro(module, SRed2Settings_SIZE);
 	result += PyModule_AddIntMacro(module, SFire3Settings_SIZE);
+	result += PyModule_AddIntMacro(module, SFire3FlexraySettings_SIZE);
 	result += PyModule_AddIntMacro(module, RadMoonDuoSettings_SIZE);
 	result += PyModule_AddIntMacro(module, SEtherBadgeSettings_SIZE);
+	result += PyModule_AddIntMacro(module, RADEPSILON_NUM_PORTS);
+	result += PyModule_AddIntMacro(module, PROXIMA_NUM_PORTS);
 	result += PyModule_AddIntMacro(module, RADEPSILON_MAX_PHY);
+	result += PyModule_AddIntMacro(module, EPSILON_88Q6113_SWITCH_A);
+	result += PyModule_AddIntMacro(module, EPSILON_88Q6113_SWITCH_B);
+	// enum
+	result += PyModule_AddIntMacro(module, EPSILON_10G_PHY1);
+	result += PyModule_AddIntMacro(module, EPSILON_10G_PHY2);
+	// end of enum -  } Epsilon_10G_PHY_select;
+
 	result += PyModule_AddIntMacro(module, SRADEpsilonSettings_SIZE);
+	// enum
+	result += PyModule_AddIntMacro(module, enumWILPortConfig_Single_Port_A);
+	result += PyModule_AddIntMacro(module, enumWILPortConfig_Single_Port_B);
+	result += PyModule_AddIntMacro(module, enumWILPortConfig_Dual_Port_A_And_B);
+	result += PyModule_AddIntMacro(module, enumWILPortConfig_Single_Port_A_And_B);
+	result += PyModule_AddIntMacro(module, _enumWILPortConfig_Total);
+	// end of enum -  };
+
+	// enum
+	result += PyModule_AddIntMacro(module, SPI_PORT_ONBOARD);
+	result += PyModule_AddIntMacro(module, SPI_PORT_EXTERNAL);
+	// end of enum -  };
+
+	// enum
+	result += PyModule_AddIntMacro(module, SPI_TYPE_WIL);
+	result += PyModule_AddIntMacro(module, SPI_TYPE_RAW);
+	// end of enum -  };
+
+	// enum
+	result += PyModule_AddIntMacro(module, SPI_MODE_MASTER);
+	result += PyModule_AddIntMacro(module, SPI_MODE_SLAVE);
+	result += PyModule_AddIntMacro(module, SPI_MODE_PMS_EMULATION);
+	// end of enum -  };
+
+	result += PyModule_AddIntMacro(module, WBMS_GATEWAY_NETWORK_NONE);
+	result += PyModule_AddIntMacro(module, WBMS_GATEWAY_NETWORK_DWCAN_01);
+	result += PyModule_AddIntMacro(module, WBMS_GATEWAY_NETWORK_DWCAN_02);
+	result += PyModule_AddIntMacro(module, WBMS_GATEWAY_NETWORK_UDP_MULTICAST);
 	result += PyModule_AddIntMacro(module, SRADBMSSettings_SIZE);
+	result += PyModule_AddIntMacro(module, SRADCometSettings_SIZE);
 	result += PyModule_AddIntMacro(module, GS_VERSION);
 	result += PyModule_AddIntMacro(module, GLOBAL_SETTINGS_SIZE);
 	result += PyModule_AddIntMacro(module, NEOVI_3G_MAX_SETTINGS_SIZE);
@@ -883,13 +1044,18 @@ int setup_module_auto_defines(PyObject * module)
 	result += PyModule_AddIntMacro(module, DeviceRADPlutoSwitchSettingsType);
 	result += PyModule_AddIntMacro(module, DeviceRADGigastarSettingsType);
 	result += PyModule_AddIntMacro(module, DeviceRADJupiterSettingsType);
-	result += PyModule_AddIntMacro(module, DeviceFire3SettingsType);
+	result += PyModule_AddIntMacro(module, DeviceRed2SettingsType);
 	result += PyModule_AddIntMacro(module, DeviceRadMoonDuoSettingsType);
 	result += PyModule_AddIntMacro(module, DeviceEtherBadgeSettingsType);
 	result += PyModule_AddIntMacro(module, DeviceRADA2BSettingsType);
 	result += PyModule_AddIntMacro(module, DeviceRADEpsilonSettingsType);
 	result += PyModule_AddIntMacro(module, DeviceOBD2LCSettingsType);
 	result += PyModule_AddIntMacro(module, DeviceRADBMSSettingsType);
+	result += PyModule_AddIntMacro(module, DeviceRADMoon3SettingsType);
+	result += PyModule_AddIntMacro(module, DeviceFire3SettingsType);
+	result += PyModule_AddIntMacro(module, DeviceFire3FlexraySettingsType);
+	result += PyModule_AddIntMacro(module, DeviceRADCometSettingsType);
+	result += PyModule_AddIntMacro(module, DeviceRed2OemSettingsType);
 	result += PyModule_AddIntMacro(module, DeviceSettingsTypeMax);
 	result += PyModule_AddIntMacro(module, DeviceSettingsNone);
 	// end of enum -  } EDeviceSettingsType;
@@ -947,7 +1113,7 @@ int setup_module_auto_defines(PyObject * module)
 	result += PyModule_AddIntMacro(module, PHYREG_FAILURE);
 	result += PyModule_AddIntMacro(module, PHYREG_INVALID_MDIO_BUS_INDEX);
 	result += PyModule_AddIntMacro(module, PHYREG_INVALID_PHY_ADDR);
-	result += PyModule_AddIntMacro(module, PHYREG_RESERVED0);
+	result += PyModule_AddIntMacro(module, PHYREG_UNSUPPORTED_MDIO_CLAUSE);
 	result += PyModule_AddIntMacro(module, PHYREG_RESERVED1);
 	result += PyModule_AddIntMacro(module, PHYREG_RESERVED2);
 	result += PyModule_AddIntMacro(module, PHYREG_RESERVED3);
@@ -976,10 +1142,43 @@ int setup_module_auto_defines(PyObject * module)
 	result += PyModule_AddIntMacro(module, networkTerminationDWCAN06);
 	result += PyModule_AddIntMacro(module, networkTerminationDWCAN07);
 	result += PyModule_AddIntMacro(module, networkTerminationDWCAN08);
+	result += PyModule_AddIntMacro(module, enhancedFlashDriver);
 	result += PyModule_AddIntMacro(module, NUM_VALID_DEVICE_FEATURES);
 	result += PyModule_AddIntMacro(module, supportedFeatureMax);
 	// end of enum -  } DeviceFeature;
 
+	// enum
+	result += PyModule_AddIntMacro(module, AccessoryOperationError);
+	result += PyModule_AddIntMacro(module, AccessoryOperationSuccess);
+	result += PyModule_AddIntMacro(module, AccessoryFlashingInitError);
+	result += PyModule_AddIntMacro(module, AccessoryFlashingEraseError);
+	result += PyModule_AddIntMacro(module, AccessoryFlashingWriteError);
+	result += PyModule_AddIntMacro(module, AccessoryFlashingReadError);
+	result += PyModule_AddIntMacro(module, AccessoryFlashingVerifyError);
+	result += PyModule_AddIntMacro(module, AccessoryFlashingDeinitError);
+	result += PyModule_AddIntMacro(module, AccessoryFlashingInvalidHardware);
+	result += PyModule_AddIntMacro(module, AccessoryFlashingInvalidDataFile);
+	result += PyModule_AddIntMacro(module, AccessoryGetVersionError);
+	result += PyModule_AddIntMacro(module, AccessoryIndexError);
+	result += PyModule_AddIntMacro(module, AccessoryParamApiVersionError);
+	result += PyModule_AddIntMacro(module, AccessoryParamSizeMismatchError);
+	result += PyModule_AddIntMacro(module, AccessoryParameterNull);
+	// end of enum -  } AccessoryOperationErrorType;
+
+	result += PyModule_AddIntMacro(module, FlashAccessoryFirmwareParams_SIZE);
+	result += PyModule_AddIntMacro(module, FlashAccessoryFirmwareParams_SIZE);
+	// enum
+	result += PyModule_AddIntMacro(module, FLASH_ACCESSORY_EPSILON_SWITCH_A);
+	result += PyModule_AddIntMacro(module, FLASH_ACCESSORY_EPSILON_SWITCH_B);
+	result += PyModule_AddIntMacro(module, FLASH_ACCESSORY_EPSILON_10G_PHY1);
+	result += PyModule_AddIntMacro(module, FLASH_ACCESSORY_EPSILON_10G_PHY2);
+	result += PyModule_AddIntMacro(module, FLASH_ACCESSORY_EPSILON_10G_PHY1_PHY2);
+	// end of enum -  } flashAccessoryIndex;
+
+	// enum
+	result += PyModule_AddIntMacro(module, FLASH_ACCESSORY_EPSILON_10G_PHY_FW_0_3_7_0);
+	// end of enum -  } epsilon10GPHYFW;
+
 	result += PyModule_AddIntMacro(module, NUM_DEVICE_FEATURE_BITFIELDS);
 	// enum
 	// end of enum -    }
